function percentageChangeFormatter (cellValue, options, rowData) {
    if (cellValue==0) return 'N/A';

    return (cellValue.indexOf('-') >= 0)  ? `<span style="color:red">${cellValue}</span>` : `<span style="color:green">${cellValue}</span>`;
}


function nameFormatter (cellValue, options, rowData){

    if (cellValue==0) return 'N/A';

    return `<img src="assets/images/icons/${rowData['Coin']}.png" class="iconImg" />  ${cellValue}  <span class="symbol">${rowData['Coin']}</span>`; 

}

function volumeFormatter (cellValue, options, rowData){

    if (cellValue==0) return 'N/A';

    let volume24hTotalCoin = parseInt(rowData['Volume24H']/rowData['Price']);

    return `$${rowData['Volume24H'].toLocaleString(undefined,{})}
            <span class="volume24hTotalCoin">${volume24hTotalCoin.toLocaleString(undefined,{})} ${rowData['Coin']}</span>`; 

}

function circulatingSupplyFormatter (cellValue, options, rowData){

    if (cellValue==0) return 'N/A';

    let volume24hTotalCoin = parseInt(rowData['Volume24H']/rowData['Price']);

    if (!!rowData['MaxSupply']) {

        const percentageOfMaxSupply = parseInt((cellValue/rowData['MaxSupply']) * 100);

        return `<span class="circulating-supply">${cellValue.toLocaleString(undefined,{})}  ${rowData['Coin']}</span>` + 
               `<div width="160" class="maxsupply-bar" title="Percentage: ${percentageOfMaxSupply}% of Max Supply of ${rowData['MaxSupply']}"><div style="width:${percentageOfMaxSupply}px" class="percentage-of-maxsupply"></div></div>`; 

    }
    
    return `${cellValue.toLocaleString(undefined,{})}`; 

}

// make sparkline
function botPosStartFormatter (cellValue, options, rowData){

    return `<button>Start</button>`;

}

function botPosStopFormatter (cellValue, options, rowData){
    

    return `<button>Stop</button>`;
}


// make sparkline
function last7DaysFormatter (cellValue, options, rowData){

    if (cellValue==0) return 'N/A';

    let lineColor = (rowData['Percentage7D'].indexOf('-') >= 0) ? 'red' : 'green';

    return `<span class="sparklines" sparkLineColor="${lineColor}" values="${JSON.parse(cellValue).join()}"></span>`;

}

// real time data via Websocket  
$(document).ready(function(){    

    // apply sparkline
    $('.sparklines').sparkline('html', { enableTagOptions: true, fillColor:false, lineWidth:2, width:'100%', height:'50px' });

    // initial coins display
    let coins = ['BTC', 'ETH', 'BNB', 'USDT'];

    coins.forEach(function(coin){

        var wss = new WebSocket(`wss://stream.binance.com:9443/ws/${coin.toLowerCase()}usdt@trade`);

        wss.onmessage = function (event) {
            var messageObject = JSON.parse(event.data)   
            $("#CoinMarket").jqGrid("setCell", coin, "Price", (messageObject.p));
            $("#CoinMarket").jqGrid("setCell", coin, "Percentage24H", (messageObject.q));
        }

    })
})


// refresh grid with selected coins only
function refreshGrid(grid) {

  if (document.getElementById('selectedCoins').selectedOptions.length === 0) {

    alert('Please select one more more coins first.');

    return;

  }

  // get list of selected coins from mulitselect dropdown 
  const selectedCoins = document.querySelector('#selectedCoins');

  // get coin list tickers only
  const coinTickers = Array.from(selectedCoins.options).filter(function (option) {
    return option.selected;
  }).map(function (option) {
    // console.log(option.dataset.balance);
    // return option.value;
    return option;

  });


  // form default coin data to populate grid
  let coins = [];

  for(let i = 0; i < coinTickers.length; i++) {

    let coin = [];

    coin["Coin"] = coinTickers[i].value;
    coin["Name"] = coinTickers[i].value;
    coin["Price"] = 0;
    coin["Percentage24H"] = 0;
    coin["CryptoBalance"] = coinTickers[i].dataset.balance;
    coin["DesiredProfitRate"] = 2;
    coin["LossRiskLimit"] = 0.02;
    coin["PurchasedPrice"] = 0;
    coin["Action1"] = '';
    coin["Action2"] = '';

    coins.push(coin);
  }


  // refresh the grid with new coin default values
  grid.jqGrid('clearGridData')
      .jqGrid('setGridParam', { data: coins })
      .trigger('reloadGrid', [{ page: 1}]);


  // pull real time coin data from websockets
  coinTickers.forEach(function(coin){

      var wss = new WebSocket(`wss://stream.binance.com:9443/ws/${coin.value.toLowerCase()}usdt@trade`);

      wss.onmessage = function (event) {
          var messageObject = JSON.parse(event.data)   
          $("#CoinMarket").jqGrid("setCell", coin.value, "Price", (messageObject.p));
          $("#CoinMarket").jqGrid("setCell", coin.value, "Percentage24H", (messageObject.q));
          $("#CoinMarket").jqGrid("setCell", coin.value, "CryptoBalance", (coin.dataset.balance));
      }

  })
}