<?php
// crypto icons
// http://cryptoicons.co/

// sample and historical data
// coinmarketcap.com

// Binance websocket trade stream API
https://docs.binance.org/api-reference/dex-api/ws-streams.html

use phpCtrl\C_DataGrid;

require_once("init.php");
require_once("../../conf.php");
require 'vendor/autoload.php';

$api = new Binance\API(BINANCE_API_KEY, BINANCE_API_SECRET);
// $api->verbosess = true;
// $balance = $api->fetch_balance({'recvWindow': 10000000});

$api->useServerTime();

$tickers = $api->prices(); // Make sure you have an updated ticker object for this to work
$balances = $api->balances($tickers);

$availCoins = [];

foreach($balances as $ticker => $value) {
  if ($value['available'] > 0) {
    $availCoins[$ticker] = $value; 
  }
}





$url = APP_URL ."/data/data.json";
$data = file_get_contents($url);
$json_output = json_decode($data, true);


$dg = new C_DataGrid($json_output, "id", "CoinMarket");


// more readable column names
$dg->set_col_title('Price', 'Live');
$dg->set_col_title('Percentage24H', '24h');
/*
$dg->set_col_title('Percentage12H', '12h');
$dg->set_col_title('Percentage4H', '4h');
$dg->set_col_title('Percentage1H', '1h');
$dg->set_col_title('Percentage15M', '15m');
$dg->set_col_title('Percentage5M', '5m');
*/
$dg->set_col_title('Action1', '');
$dg->set_col_title('Action2', '');

$dg->set_col_readonly('Name, Price, Percentage24H, Percentage12H, Percentage4H, Percentage1H, Percentage15M, Percentage5M, CryptoBalance, PurchasedPrice, Action1, Action2');


$dg->set_col_readonly('Name, Price, Percentage24H, CryptoBalance, PurchasedPrice, Action1, Action2');


// hide columns not showing
$dg->set_col_hidden("Coin");
$dg->set_col_hidden("MaxSupply");

$dg->set_theme('bootstrap');

// remove caption
$dg->set_caption(false);

$dg->enable_rownumbers(true);

// align numbers
$dg->set_col_align('Price', 'right');
$dg->set_col_align('Percentage24H', 'right');
//$dg->set_col_align('Percentage7D', 'right');
$dg->set_col_align('MarketCap', 'right');
$dg->set_col_align('Volume24H', 'right');
$dg->set_col_align('CirculatingSupply', 'right');
$dg->set_col_align('CryptoBalance', 'right');


// price formatter
$dg->set_col_currency('Price', '$');
$dg->set_col_currency('CryptoBalance', '$');
$dg->set_col_currency('Volume24H', '$');
$dg->set_col_currency('CirculatingSupply', '');

// column style
$dg->set_col_property('Coin', array('classes'=>'coin'));
$dg->set_col_property('Name', array('classes'=>'name'));

// row color and hightlight
$dg -> set_row_color('white', 'white', 'white');

// currency sort fix (default string type)
$dg -> set_col_property("Price",  array("sorttype"=>"currency")); 
$dg -> set_col_property("CryptoBalance",  array("sorttype"=>"currency"));
$dg -> set_col_property("Volume24H",  array("sorttype"=>"currency")); 
$dg -> set_col_property("CirculatingSupply",  array("sorttype"=>"integer")); 

// custom formatter (icon name symbol)
$dg->set_col_property('Name', array('formatter'=>'###nameFormatter###')); // must have ###
$dg->set_col_property('Volume24H', array('formatter'=>'###volumeFormatter###')); // must have ###
$dg->set_col_property('CirculatingSupply', array('formatter'=>'###circulatingSupplyFormatter###')); // must have ###
$dg->set_col_property('Last7Days', array('formatter'=>'###last7DaysFormatter###')); // must have ###
$dg->set_col_property('Percentage24H', array('formatter'=>'###percentageChangeFormatter###')); // must have ###
//$dg->set_col_property('Percentage7D', array('formatter'=>'###percentageChangeFormatter###')); // must have ###

$dg->set_col_property('Action1', array('formatter'=>'###botPosStartFormatter###')); // must have ###
$dg->set_col_property('Action2', array('formatter'=>'###botPosStopFormatter###')); // must have ###

// use tick symbol as key 
$dg->set_sql_key('Coin');

// responsive grid
//$dg -> enable_autowidth(true);

$dg->enable_edit('INLINE');

$dg -> display(false);
$grid = $dg -> get_display(true); 




$loader = new \Twig\Loader\FilesystemLoader('views');
$twig = new \Twig\Environment($loader, [
    'cache' => 'cache',
    'auto_reload' => true  // disable cache
]);

$template = $twig->load('home.php');

echo $template->render([
    'APP_URL' => APP_URL,
    'availCoins' => $availCoins,
    'grid' => $grid
]);